

TI Vendor Map Generation Profiling
**********************************

.. seealso:: :func:`profiling.sourcing.vendors.profile_vendor_genvmap`

:download:`Raw execution profile <../../../profiling/sourcing/genvmap/ti.profile>`
:download:`SVG of execution profile <../../../profiling/sourcing/genvmap/ti.profile.svg>`

.. rubric:: Execution Profile

.. image:: ../../../profiling/sourcing/genvmap/ti.profile.svg

.. rubric:: pstats Output

.. literalinclude:: ../../../profiling/sourcing/genvmap/ti.profile.stats

